# LangSci

This package provides tools for authoring open access books. 

The python packages available in pypi are in the folder `langsci`

A couple of wrapper scripts for these packages for the command line are in the folder `wrapperscripts`. 

Some more random scripts which we use but which are not related to any of the packages are found in the folder `standalonescripts`

